/***********************************************************************
*                                                                             
*  Created By:  Chuck Hellebuyck 10/31/08                                     
*                                                                             
*  Versions:                                                                  
*                                                                             
*  MAJ.MIN - AUTHOR - CHANGE DESCRIPTION                                      
*                                                                             
*   1.0    - Sequence thru 0 to 9 on LED display at a 1/2 second rate
*
* Common Anode LED display driven by PortC.                                             
*         _
*         A
*  F|           |B
*          
*         _
*         G
*  E|           |C
*         _      .
*         D     dp
* 
* Connections
* ------------
* PORTC.0 - C
* PORTC.1 - G
* PORTC.2 - B
* PORTC.3 - D
* PORTC.4 - E
* PORTC.5 - F
* PORTC.6 - A
* no connection - dp
***********************************************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <htc.h>			// Include HITECH CC header file

//*** LED Display Conversion Table ***
const zero =  0b00000010;		//Form 0 Digit
const one =   0b01111010;		//Form 1 Digit
const two =   0b00100001; 		//Form 2 Digit
const three = 0b00110000; 		//Form 3 Digit
const four =  0b01011000; 		//Form 4 Digit
const five =  0b00010100; 		//Form 5 Digit
const six =   0b00000100; 		//Form 6 Digit
const seven = 0b00111010; 		//Form 7 Digit
const eight = 0b00000000; 		//Form 8 Digit
const nine =  0b00010000; 		//Form 9 Digit

/*
PIC16F690 Configuration
*/
__CONFIG (INTIO & WDTDIS & MCLRDIS & UNPROTECT); 
//Internal clock, Watchdog off, MCLR off, Code Unprotected

void pause( unsigned short usvalue );		//Establish pause routine function


main()
{
unsigned char state_led = 0; 	//Create 8 bit variable to store switch count

ANSEL =	0;			// Intialize A/D ports off
ANSELH = 0;				// Intialize A/D ports off
CM1CON0 = 0;			// Initialize Comparator 1 off
CM2CON0 = 0;			// Initialize Coparator 2 off

PORTC = 0x00;			//Clear PortC port
TRISC = 0x00;			//All PortC I/O outputs

while(1==1)				//loop forever
{

	state_led++;		//  increment the LED state variable
	switch (state_led)
		 {
			case 1:				// Display 1
				PORTC = one;
				break;
			case 2:				// Display 2
				PORTC = two;
				break;
			case 3:				// Display 3
				PORTC = three;
				break;
			case 4:				// Display 4
				PORTC = four;	
				break;
			case 5:				// Display 5
				PORTC = five;
				break;
			case 6:				// Display 6
				PORTC = six;
				break;
			case 7:				// Display 7
				PORTC = seven;
				break;
			case 8:				// Display 8
				PORTC = eight;	
				break;
			case 9:				// Display 9
				PORTC = nine;
				break;
			default:		// If state_led > 3 reset switch count to zero
				state_led = 0;		// Display Zero	
				PORTC = zero;
				break;
			} //end switch

		pause (500);			// Delay 500 milliseconds and check again
		

}	//End while
}	//end main 