/* Timer 1 Interrupt. The Timer 1 is a 16 bit timer
and this project uses it to create an accurate 0.5 second timebase.
The project will light the LEDs on the PICkit 2 development board
in sequence moving to the right every two seconds. When the final
LED is lit, the program jumps back to the first DS1 LED after the 
two second delay. The program continues lighting the LEDs in a 
continuous loop. */
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <htc.h>

__CONFIG (INTIO & WDTDIS & MCLRDIS & UNPROTECT);


unsigned char TOC;			// Timer overflow counter variable


/* This is where we go when Timer 1 overflow interrupt occurs */

void interrupt isr(void)
{
if (TMR1IF = 1)
	{
	TMR1H = 0x0B;			// Preset Timer 1 to 3035 decimal 
	TMR1L = 0xDB;			//  using $0BDB hex
	TOC = TOC +1;			// Increment the timer overflow count
	TMR1IF = 0;				// Clear Timer1 overflow interrupt flag
	}
}
	
void main(void)
{
	
ANSEL = 0;		// Set PORTA all Digital
ANSELH = 0;
CM1CON0 = 0;	// Comparator 1 off
CM2CON0 = 0;	// Comparator 2 off

TRISA = 0;		// All PORTA Outputs
TRISC = 0;		// All PORTC Outputs


/* Timer1 Register Setup */

TMR1H = 0x0B;				// Preset Timer 1 to 3035 
TMR1L = 0xDB;				//  using $0BDB hex
T1CON = 0b00110000;			// Setup Timer1 with 1:8 prescaler
PIE1 = 0b00000001;			// Enable Timer1 Interrupt only
INTCON = 0b11000000;		// Enable interrupts GIE =1, PEIE = 1
TMR1ON = 1;					// Timer 1 On

/* PORTs and Global Variables Initialization */

PORTC = 1;					// Initialize all LEDs off
TRISC = 0;					// PortC all Outputs
TOC = 0;					// Initialize counter to zero

/* Continuous Loop */

while (1==1)
	{
	if (TOC == 4)
		{
		PORTC = PORTC << 1;     // Light next LED by shifting bit left
		TOC = 0;				// Reset counter to zero
		}
	
	if (PORTC > 8)
		{
		PORTC = 1;				// Reset PORTC to Light DS1 LED
		}

	} // End while

} // End main
