/* Hardware PWM example
This simple example controls the duty cycle of the PWM output
P1A (RC5) on the PIC16F690. The frequency of the signal will
run at 500 hz and the duty cycle will adjust from 0% to 100%
based on the value read at ADC input AN0 connected to a 
potentiometer.The Output from RC5 is jumpered to RC3 and drives
the DS4 LED. As you turn the potentiometer the brightness of
the DS4 LED changes.
The hardware used is the PICkit 2 Low Pin Count Demo Board.
*/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <htc.h>
#include "pause.h"

/* PIC16F690 Configuration Settings */
__CONFIG (INTIO & WDTDIS & MCLRDIS & UNPROTECT );
 //Internal clock, Watchdog off, MCLR off, Code Unprotected

void main()
{

ANSEL = 0;		//ADC pins set to digital
ANSELH = 0;
CM1CON0 = 0;	// Comparators off
CM2CON0 = 0;
	
// ********  PWM Setup ************************	

	TRISC = 0xFF;
	CCP1CON = 0;				//Turn CCP Module Off
	// Setup PWM
	PR2 = 124;					// Set PWM period
	CCPR1L = 0b00111110;				// Duty = 50%
	TMR2IE = 0;					// Disable Timer 2 Interrupt
	T2CKPS0 = 1;				// Set timer2 prescaler to 16
	T2CKPS1 = 1;
	CCP1CON = 0b00001100;		// Configure PWM Mode, Set DB bits to 10
	TMR2ON = 1;					// Turn on Timer 2
	 
	while (TMR2IF ==0)			// Wait for start of period
		{}
	
	TRISC5 = 0;					// Start PWM Signal by making P1A an output 

// ***** A/D Setup *************
	
	TRISA0 = 1;					// Make RA0/AN0 an Input
	ANSEL = 0b00000001;			// Configure RA0 and Analog to Digital input
	ADCON0 = 0b00000000;		// Configure A/D to use AN0, left justified

	while(1)
	{
		ADON = 1; 				// A/D Converter on;
		GODONE = 1;				// Start A/D conversion on AN0
		while(GODONE == 1); 	// Wait for conversion to complete

		// Adjust PWM Duty Cycle with AN0 A/D Value
		CCPR1L = ADRESH;
		pause(250);			//Delay for 1/4 second
	}	
}

